Module server

Module server 

MCP server construction and transport serving. MCP server construction and transport serving.

This module is the main bridge from parsed skills to runnable MCP servers. It supports both local stdio serving and remote streamable HTTP serving.

Modules

handler

Structs

HttpAuth
HttpServeLimits

Functions

build_server
Build a SkillsServer from skill search paths.
serve_http
Run the MCP server over streamable HTTP.
serve_stdio
Run the MCP server over stdio.