MCP server construction and transport serving. MCP server construction and transport serving.
This module is the main bridge from parsed skills to runnable MCP servers. It supports both local stdio serving and remote streamable HTTP serving.
Modules
Structs
Functions
- build_
server - Build a SkillsServer from skill search paths.
- serve_
http - Run the MCP server over streamable HTTP.
- serve_
stdio - Run the MCP server over stdio.